@@ -9,17 +9,14 @@ discord_api_base = "https://discordapp.com/api/v9"
 discord_api_authorize = discord_api_base + "/oauth2/authorize"
 discord_api_token = discord_api_base + "/oauth2/token"
 
-class Flaskord:
-    def __init__(self, token: str = None):
-        if token:
-            self.headers = {
-                'Accept': 'application/json',
-                'Content-Type': 'application/json',
-                "authorization": f"Bot {token}",
-                "intents": "GUILD_MEMBERS"
-            }
-        else:
-            raise UndefinedToken("Token is not set")
+class client:
+    def __init__(self, token):
+        self.headers = {
+            'Accept': 'application/json',
+            'Content-Type': 'application/json',
+            "authorization": f"Bot {token}",
+            "intents": "GUILD_MEMBERS" # it doesn't need it, but I'll leave it here :/
+        }
 
     def __run__(self, route, method, payload=None):
         route = discord_api_base + route
@@ -60,8 +57,16 @@ class Flaskord:
                   guild_id: Union[str, int]) -> dict:
 
         resp = self.__run__(route=f"/guilds/{guild_id}?with_counts=true", method='GET')
+        guild_channels = self.__run__(route=f"/guilds/{guild_id}/channels", method='GET')
+
+        text_channels = [i for i in guild_channels if i["type"] in (0, 5, 15)]
+        voice_channels = [i for i in guild_channels if i["type"] == 2]
+        categories = [i for i in guild_channels if i["type"] == 4]
+
+        resp["text_channels"] = text_channels
+        resp["voice_channels"] = voice_channels
+        resp["categories"] = categories
         resp["member_count"] = resp["approximate_member_count"]
-        return resp
 
     # advanced methods
 
